unit UThreads;

interface

uses
  Classes, ExtCtrls, Windows, ComCtrls, SkinCtrls, Forms, Dialogs, Messages;

type

  TProgressBarThread = class(TThread)
  private
    pb: TspSkinGauge;
    FStep: Integer;
  protected
    procedure Execute; override;
    procedure MoveTh;
  public
    property Step:Integer read FStep write FStep;
    constructor Create(Box: TspSkinGauge; AStep:Integer; ThreadPriority: TThreadPriority);
    procedure ShowMessage;
  end;

  TPanelColorThread = class(TThread)
  private
    pnb: TPanel;
    FColor: Integer;
  protected
    procedure Execute; override;
    procedure ChangeColor;
  public
    constructor Create(APanel: TPanel; ThreadPriority: TThreadPriority);
  end;

  TBallThread = class(TThread)
  private
    sh: TShape;
    pnl:TspSkinPanel;
    FDirection: Integer;
  protected
    procedure Execute; override;
    procedure ChangePosition;
  public
    constructor Create(AShape: TShape; APanel: TspSkinPanel; ThreadPriority: TThreadPriority);
  end;

implementation

uses
  graphics, FMain;

{ TProgressBarThread }
constructor TProgressBarThread.Create(Box: TspSkinGauge; AStep:Integer;
                                      ThreadPriority: TThreadPriority);
begin
  inherited Create(False);
  Self.FStep := AStep;
  pb := Box;
end;

procedure TProgressBarThread.ShowMessage;
begin
  Suspend;
  Form1.spSkinMessage1.MessageDlg('Show message from Thread!',
    mtInformation, [mbOk], 0);
  Resume;
end;

procedure TProgressBarThread.Execute;
begin

    while true do begin
      Synchronize(MoveTh);
      Sleep(50);
    end;

end;

procedure TProgressBarThread.MoveTh();
begin
  pb.Value := (pb.Value + FStep) MOD 100;
end;


{ TPanelColorThread }
procedure TPanelColorThread.ChangeColor;
begin
  FColor := RGB(Random(255), Random(255), Random(255));
  pnb.Color := FColor;
end;

constructor TPanelColorThread.Create(APanel: TPanel;
                                     ThreadPriority: TThreadPriority);
begin
  inherited Create(False);
  pnb := APanel;
end;

procedure TPanelColorThread.Execute;
begin
  Randomize;

  while true do begin
    Synchronize(ChangeColor);
    sleep(60);
  end;

end;

{ TBallThread }

procedure TBallThread.ChangePosition;
begin
  sh.Top := sh.Top + FDirection;

  if (FDirection > 0) and (sh.Top + sh.Height + Abs(FDirection) >= (pnl.Height)) then begin
    FDirection := -5;
    Exit;
  end;
  if (FDirection < 0) and (sh.Top <= Abs(FDirection)) then begin
    FDirection := 5;
    Exit;
  end;
end;

constructor TBallThread.Create(AShape: TShape; APanel:TspSkinPanel;
                               ThreadPriority: TThreadPriority);
begin

  inherited Create(False);

  sh := AShape;
  pnl := APanel;
  FDirection := 5;

end;

procedure TBallThread.Execute();
begin

  while true do begin
    Synchronize(ChangePosition);
    sleep(20);
  end;

end;

end.

